.. :changelog:

History
-------

0.1.2 (2015-08-19)
++++++++++++++++++

* Added package requirements

0.1.1 (2015-08-19)
++++++++++++++++++

* Switched to `pip.get_installed_distributions` to get a package list
* minor documentation tweaks

0.1.0 (2015-08-19)
++++++++++++++++++

* First release on PyPI.
